//***************************************************************************
//
// $Source$
// $Revision$
//
//
//   Latis Networks, Inc. (d/b/a StillSecure)
//     www.stillsecure.com
//     www.stillsecure.org
//
//
//   Copyright (C) 2005-2006 Latis Networks, Inc. (d/b/a StillSecure)
//
//    This file is part of SAPQ.
//
//    SAPQ is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    SAPQ is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAPQ; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
//
//
//     Project: Safe Access Packet Queuing Daemon
//     Module: SAPQ
//     Class: DHCPWatcher
//     Author: Jim Guggemos
//     Description: Class that monitors DHCP packets from PacketQueue
//
// $Date$
//
//***************************************************************************

#ifndef __DHCPWatcher_H__
#define __DHCPWatcher_H__

#include "PacketQueue.h"
#include "Mutex.h"
#include <pthread.h>
#include <string>
#include <netinet/in.h>

class HashManager;
class HwAddr;

class DHCPWatcher : public PacketQueueListener
{
public:
    DHCPWatcher(HashManager &hashmgr, int queueNum, bool reverse);
    virtual ~DHCPWatcher();

    bool start();
    void stop();

    bool decodePacket(const unsigned char *data, const int len, HwAddr &ha, in_addr_t &srcip, in_addr_t &giaddr);

    // Required for PacketQueueListener interface
    virtual bool onPacket(unsigned char **payload, int *payloadLen);
    struct udphdr
    {
        short srcport;
        short dstport;
        short len;
        short cksum;
    };
protected:
    void run();

private:
    PacketDispatcher *m_dispatcher;
    pthread_t m_threadId;
    HashManager &m_hashmgr;
    const int m_queueNum;
    const bool m_reverse;
    Mutex m_dispMutex; // used to protect when deleting dispatcher
    void writeTag(unsigned char *payload, int len, const char *tag);

    static void *threadRun(void*);
};

#endif // __DHCPWatcher_H__
