#!/bin/sh -
#
# $Id$
#
# Used by "make gpl_release" to create a tar file to release the source
# code for GPL compliance.
#

VERSION_FILE=VERSION
MAJOR_VERSION=`grep MAJOR_VERSION $VERSION_FILE | awk '{print $2}'`
MINOR_VERSION=`grep MINOR_VERSION $VERSION_FILE | awk '{print $2}'`

if [ $# -eq 0 ]; then
    echo "No arguments given.  This should be invoked by executing:"
    echo "  make gpl_release"
    exit 1
fi

sources="$@"

echo "Cleaning up old GPL release directories, if any"
for i in sapq sapq-*; do
    if [ -d "$i" ]; then
        echo "  + rm -rf $i"
        rm -rf $i
    fi
done

dirname="sapq-$MAJOR_VERSION.$MINOR_VERSION"
tarname=$dirname.tgz

echo "Creating new GPL release directory"
echo "  + mkdir $dirname"
mkdir $dirname

echo "Copying over files stripping some header comment info:"
for i in $sources; do
    echo "  + $i"
    sed -e '/\/\/ *\$''Source: \/cvs/d' -e '/\/\/ *Author: /d' < $i \
        > $dirname/$i
done
echo "  + COPYING"
cp -p COPYING $dirname

echo "Creating tar file: $tarname"
tar cfz $tarname --owner=0 --group=0 $dirname

echo "Cleaning up GPL release directory"
echo "  + rm -rf $dirname"
rm -rf $dirname
